.. _imputation_ref:

:mod:`biolearn.imputation`: Data Imputation Utilities
=================================================

.. automodule:: biolearn.imputation
   :no-members:
   :no-inherited-members:

This module provides a set of functions for imputing missing values in DNA methylation datasets. These functions allow for various strategies of imputation, from simple averaging to more complex hybrid methods.

**Functions**:

.. currentmodule:: biolearn.imputation

.. autosummary::
   :toctree: generated/
   :template: function.rst

   impute_from_standard
   impute_from_average
   hybrid_impute